# Metatype

Implements the base metaformat types for different versions of metaformat.

This package provides classes derived from base `dict` class, with modified constructors, in order to validate represent data items following metaformat's specific version (specific metaformats).


It is organized as follows:


```
metatype
  metatype
    mft
      <N>
    rfc
      <N>
    iso
      <N>
```
